from a10sdk.common.A10BaseClass import A10BaseClass


class Template(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param redirect_wlist_fail: {"description": "Redirect Whitelist Failure", "format": "counter", "type": "number", "oid": "119", "optional": true, "size": "2"}
    :param cookie_encrypt_limit_exceeded: {"description": "Cookie Encrypt Limit Exceeded", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "2"}
    :param wsdl_succ: {"description": "WSDL Success", "format": "counter", "type": "number", "oid": "75", "optional": true, "size": "2"}
    :param sqlia_chk_url_succ: {"description": "SQLIA Check URL Success", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "2"}
    :param bot_check_succ: {"description": "Botnet Check Success", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param buf_ovf_cookie_name_len_fail: {"description": "Buffer Overflow - Cookie Name Length Failure", "format": "counter", "type": "number", "oid": "98", "optional": true, "size": "2"}
    :param redirect_wlist_learn: {"description": "Redirect Whitelist Learn", "format": "counter", "type": "number", "oid": "120", "optional": true, "size": "2"}
    :param xml_limit_elem_child: {"description": "XML Limit Element Child", "format": "counter", "type": "number", "oid": "104", "optional": true, "size": "2"}
    :param buf_ovf_parameter_value_len_fail: {"description": "Buffer Overflow - HTML Parameter Value Length Failure", "format": "counter", "type": "number", "oid": "93", "optional": true, "size": "2"}
    :param ccn_mask_visa: {"description": "Credit Card Number Mask Visa", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "2"}
    :param xss_chk_cookie_succ: {"description": "XSS Check Cookie Success", "format": "counter", "type": "number", "oid": "53", "optional": true, "size": "2"}
    :param buf_ovf_cookies_len_fail: {"description": "Buffer Overflow - Cookies Length Failure", "format": "counter", "type": "number", "oid": "87", "optional": true, "size": "2"}
    :param redirect_wlist_succ: {"description": "Redirect Whitelist Success", "format": "counter", "type": "number", "oid": "118", "optional": true, "size": "2"}
    :param json_check_failure: {"description": "JSON Check Failure", "format": "counter", "type": "number", "oid": "82", "optional": true, "size": "2"}
    :param xss_chk_post_reject: {"description": "XSS Check Post Rejected", "format": "counter", "type": "number", "oid": "61", "optional": true, "size": "2"}
    :param xss_chk_url_reject: {"description": "XSS Check URL Rejected", "format": "counter", "type": "number", "oid": "58", "optional": true, "size": "2"}
    :param form_consistency_succ: {"description": "Form Consistency Success", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param xml_limit_cdata_len: {"description": "XML Limit CData Length", "format": "counter", "type": "number", "oid": "102", "optional": true, "size": "2"}
    :param xml_check_failure: {"description": "XML Check Failure", "format": "counter", "type": "number", "oid": "84", "optional": true, "size": "2"}
    :param num_resets: {"description": "Number Resets", "format": "counter", "type": "number", "oid": "66", "optional": true, "size": "2"}
    :param referer_check_succ: {"description": "Referer Check Success", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "2"}
    :param sqlia_chk_post_succ: {"description": "SQLIA Check Post Success", "format": "counter", "type": "number", "oid": "50", "optional": true, "size": "2"}
    :param xss_chk_url_sanitize: {"description": "XSS Check URL Sanitized", "format": "counter", "type": "number", "oid": "57", "optional": true, "size": "2"}
    :param cookie_encrypt_succ: {"description": "Cookie Encrypt Success", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "2"}
    :param buf_ovf_parameter_total_len_fail: {"description": "Buffer Overflow - HTML Parameter Total Length Failure", "format": "counter", "type": "number", "oid": "94", "optional": true, "size": "2"}
    :param soap_check_succ: {"description": "Soap Check Success", "format": "counter", "type": "number", "oid": "72", "optional": true, "size": "2"}
    :param max_cookies_fail: {"description": "Max Cookies Failure", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "2"}
    :param json_limit_array_value_count: {"description": "JSON Limit Array Value Count", "format": "counter", "type": "number", "oid": "111", "optional": true, "size": "2"}
    :param xml_limit_entity_exp_depth: {"description": "XML Limit Entity Exp Depth", "format": "counter", "type": "number", "oid": "108", "optional": true, "size": "2"}
    :param json_check_succ: {"description": "JSON Check Success", "format": "counter", "type": "number", "oid": "83", "optional": true, "size": "2"}
    :param resp_code_hidden: {"description": "Response Code Hidden", "format": "counter", "type": "number", "oid": "62", "optional": true, "size": "2"}
    :param xml_sqlia_chk_fail: {"description": "XML Sqlia Check Failure", "format": "counter", "type": "number", "oid": "78", "optional": true, "size": "2"}
    :param xss_chk_post_succ: {"description": "XSS Check Post Success", "format": "counter", "type": "number", "oid": "59", "optional": true, "size": "2"}
    :param form_consistency_fail: {"description": "Form Consistency Failure", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param http_check_fail: {"description": "Http Check Failure", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "2"}
    :param url_check_succ: {"description": "URL Check Success", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param sqlia_chk_url_sanitize: {"description": "SQLIA Check URL Sanitized", "format": "counter", "type": "number", "oid": "48", "optional": true, "size": "2"}
    :param xss_chk_cookie_reject: {"description": "XSS Check Cookie Rejected", "format": "counter", "type": "number", "oid": "55", "optional": true, "size": "2"}
    :param max_entities_fail: {"description": "Max Entities Failure", "format": "counter", "type": "number", "oid": "96", "optional": true, "size": "2"}
    :param xml_limit_attr: {"description": "XML Limit Attribue", "format": "counter", "type": "number", "oid": "99", "optional": true, "size": "2"}
    :param http_method_check_fail: {"description": "Http Method Check Failure", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "2"}
    :param form_non_ssl_reject: {"description": "Form Non SSL Rejected", "format": "counter", "type": "number", "oid": "67", "optional": true, "size": "2"}
    :param xss_chk_post_sanitize: {"description": "XSS Check Post Sanitized", "format": "counter", "type": "number", "oid": "60", "optional": true, "size": "2"}
    :param form_set_no_cache: {"description": "Form Set No Cache", "format": "counter", "type": "number", "oid": "121", "optional": true, "size": "2"}
    :param xml_schema_succ: {"description": "XML Schema Success", "format": "counter", "type": "number", "oid": "77", "optional": true, "size": "2"}
    :param sqlia_chk_url_reject: {"description": "SQLIA Check URL Rejected", "format": "counter", "type": "number", "oid": "49", "optional": true, "size": "2"}
    :param xml_check_succ: {"description": "XML Check Success", "format": "counter", "type": "number", "oid": "85", "optional": true, "size": "2"}
    :param sess_check_none: {"description": "Session Check None", "format": "counter", "type": "number", "oid": "69", "optional": true, "size": "2"}
    :param xml_limit_namespace: {"description": "XML Limit Namespace", "format": "counter", "type": "number", "oid": "109", "optional": true, "size": "2"}
    :param wsdl_fail: {"description": "WSDL Failure", "format": "counter", "type": "number", "oid": "74", "optional": true, "size": "2"}
    :param post_form_check_succ: {"description": "Post Form Check Success", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "2"}
    :param buf_ovf_query_len_fail: {"description": "Buffer Overflow - Query Length Failure", "format": "counter", "type": "number", "oid": "95", "optional": true, "size": "2"}
    :param sqlia_chk_post_reject: {"description": "SQLIA Check Post Rejected", "format": "counter", "type": "number", "oid": "52", "optional": true, "size": "2"}
    :param form_password_autocomplete: {"description": "Form Password Autocomplete", "format": "counter", "type": "number", "oid": "117", "optional": true, "size": "2"}
    :param xml_xss_chk_fail: {"description": "XML XSS Check Failure", "format": "counter", "type": "number", "oid": "80", "optional": true, "size": "2"}
    :param buf_ovf_url_len_fail: {"description": "Buffer Overflow - URL Length Failure", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param buf_ovf_cookie_len_fail: {"description": "Buffer Overflow - Cookie Length Failure", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param form_csrf_tag_succ: {"description": "Form CSRF tag Success", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param xss_chk_cookie_sanitize: {"description": "XSS Check Cookie Sanitized", "format": "counter", "type": "number", "oid": "54", "optional": true, "size": "2"}
    :param xml_limit_entity_exp: {"description": "XML Limit Entity Exp", "format": "counter", "type": "number", "oid": "107", "optional": true, "size": "2"}
    :param ccn_mask_diners: {"description": "Credit Card Number Mask Diners", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "2"}
    :param sess_check_succ: {"description": "Session Check Success", "format": "counter", "type": "number", "oid": "70", "optional": true, "size": "2"}
    :param json_limit_depth: {"description": "JSON Limit Depth", "format": "counter", "type": "number", "oid": "112", "optional": true, "size": "2"}
    :param cookie_encrypt_skip_rcache: {"description": "Cookie Encrypt Skip RCache", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "2"}
    :param learn_updates: {"description": "Learning Updates", "format": "counter", "type": "number", "oid": "64", "optional": true, "size": "2"}
    :param req_denied: {"description": "Requests Denied", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param http_check_succ: {"description": "Http Check Success", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "2"}
    :param req_allowed: {"description": "Requests Allowed", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param json_limit_object_member_count: {"description": "JSON Limit Object Number Count", "format": "counter", "type": "number", "oid": "113", "optional": true, "size": "2"}
    :param bot_check_fail: {"description": "Botnet Check Failure", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param uri_wlist_fail: {"description": "URI White List Failure", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "2"}
    :param uri_blist_fail: {"description": "URI Black List Failure", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "2"}
    :param xml_limit_namespace_uri_len: {"description": "XML Limit Namespace URI Length", "format": "counter", "type": "number", "oid": "110", "optional": true, "size": "2"}
    :param sqlia_chk_post_sanitize: {"description": "SQLIA Check Post Sanitized", "format": "counter", "type": "number", "oid": "51", "optional": true, "size": "2"}
    :param ccn_mask_amex: {"description": "Credit Card Number Mask Amex", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "2"}
    :param num_drops: {"description": "Number Drops", "format": "counter", "type": "number", "oid": "65", "optional": true, "size": "2"}
    :param referer_check_fail: {"description": "Referer Check Failure", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "2"}
    :param post_form_check_sanitize: {"description": "Post Form Check Sanitized", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "2"}
    :param cookie_decrypt_succ: {"description": "Cookie Decrypt Success", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "2"}
    :param max_parameters_fail: {"description": "Max Parameters Failure", "format": "counter", "type": "number", "oid": "97", "optional": true, "size": "2"}
    :param url_check_fail: {"description": "URL Check Failure", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param xml_schema_fail: {"description": "XML Schema Failure", "format": "counter", "type": "number", "oid": "76", "optional": true, "size": "2"}
    :param form_non_post_reject: {"description": "Form Non Post Rejected", "format": "counter", "type": "number", "oid": "68", "optional": true, "size": "2"}
    :param buf_ovf_hdrs_len_fail: {"description": "Buffer Overflow - Headers length Failure", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "2"}
    :param uri_wlist_succ: {"description": "URI White List Success", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "2"}
    :param form_non_masked_password: {"description": "Form Non Masked Password", "format": "counter", "type": "number", "oid": "115", "optional": true, "size": "2"}
    :param buf_ovf_line_len_fail: {"description": "Buffer Overflow - Line Length Failure", "format": "counter", "type": "number", "oid": "91", "optional": true, "size": "2"}
    :param ccn_mask_discover: {"description": "Credit Card Number Mask Discover", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "2"}
    :param ssn_mask: {"description": "Social Security Number Mask", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "2"}
    :param json_limit_string: {"description": "JSON Limit String", "format": "counter", "type": "number", "oid": "114", "optional": true, "size": "2"}
    :param resp_hdrs_filtered: {"description": "Response Headers Filtered", "format": "counter", "type": "number", "oid": "63", "optional": true, "size": "2"}
    :param ccn_mask_mastercard: {"description": "Credit Card Number Mask Mastercard", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "2"}
    :param xml_sqlia_chk_succ: {"description": "XML Sqlia Check Success", "format": "counter", "type": "number", "oid": "79", "optional": true, "size": "2"}
    :param max_hdrs_fail: {"description": "Max Headers Failure", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param xml_limit_attr_name_len: {"description": "XML Limit Name Length", "format": "counter", "type": "number", "oid": "100", "optional": true, "size": "2"}
    :param form_non_ssl_password: {"description": "Form Non SSL Password", "format": "counter", "type": "number", "oid": "116", "optional": true, "size": "2"}
    :param buf_ovf_hdr_value_len_fail: {"description": "Buffer Overflow - Header Value Length Failure", "format": "counter", "type": "number", "oid": "89", "optional": true, "size": "2"}
    :param uri_blist_succ: {"description": "URI Black List Success", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "2"}
    :param sess_check_fail: {"description": "Session Check Failure", "format": "counter", "type": "number", "oid": "71", "optional": true, "size": "2"}
    :param buf_ovf_hdr_name_len_fail: {"description": "Buffer Overflow - Header Name Length Failure", "format": "counter", "type": "number", "oid": "88", "optional": true, "size": "2"}
    :param resp_denied: {"description": "Responses Denied", "format": "counter", "type": "number", "oid": "122", "optional": true, "size": "2"}
    :param pcre_mask: {"description": "PCRE Mask", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "2"}
    :param xml_limit_elem: {"description": "XML Limit Element", "format": "counter", "type": "number", "oid": "103", "optional": true, "size": "2"}
    :param buf_ovf_parameter_name_len_fail: {"description": "Buffer Overflow - HTML Parameter Name Length Failure", "format": "counter", "type": "number", "oid": "92", "optional": true, "size": "2"}
    :param xml_limit_attr_value_len: {"description": "XML Limit Value Length", "format": "counter", "type": "number", "oid": "101", "optional": true, "size": "2"}
    :param xml_limit_elem_depth: {"description": "XML Limit Element Depth", "format": "counter", "type": "number", "oid": "105", "optional": true, "size": "2"}
    :param ccn_mask_jcb: {"description": "Credit Card Number Mask Jcb", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "2"}
    :param cookie_decrypt_fail: {"description": "Cookie Decrypt Failure", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "2"}
    :param buf_ovf_cookie_value_len_fail: {"description": "Buffer Overflow - Cookie Value Length Failure", "format": "counter", "type": "number", "oid": "86", "optional": true, "size": "2"}
    :param buf_ovf_max_data_parse_fail: {"description": "Buffer Overflow - Max Data Parse Failure", "format": "counter", "type": "number", "oid": "90", "optional": true, "size": "2"}
    :param total_req: {"description": "Total Requests", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param xml_limit_elem_name_len: {"description": "XML Limit Element Name Length", "format": "counter", "type": "number", "oid": "106", "optional": true, "size": "2"}
    :param url_check_learn: {"description": "URL Check Learn", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param http_method_check_succ: {"description": "Http Method Check Success", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param xss_chk_url_succ: {"description": "XSS Check URL Success", "format": "counter", "type": "number", "oid": "56", "optional": true, "size": "2"}
    :param referer_check_redirect: {"description": "Referer Check Redirect", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "2"}
    :param post_form_check_reject: {"description": "Post Form Check Rejected", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "2"}
    :param cookie_encrypt_fail: {"description": "Cookie Encrypt Failure", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "2"}
    :param soap_check_failure: {"description": "Soap Check Failure", "format": "counter", "type": "number", "oid": "73", "optional": true, "size": "2"}
    :param form_csrf_tag_fail: {"description": "Form CSRF tag Failure", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param xml_xss_chk_succ: {"description": "XML XSS Check Success", "format": "counter", "type": "number", "oid": "81", "optional": true, "size": "2"}
    :param buf_ovf_post_size_fail: {"description": "Buffer Overflow - Post size Failure", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "template"
        self.DeviceProxy = ""
        self.redirect_wlist_fail = ""
        self.cookie_encrypt_limit_exceeded = ""
        self.wsdl_succ = ""
        self.sqlia_chk_url_succ = ""
        self.bot_check_succ = ""
        self.buf_ovf_cookie_name_len_fail = ""
        self.redirect_wlist_learn = ""
        self.xml_limit_elem_child = ""
        self.buf_ovf_parameter_value_len_fail = ""
        self.ccn_mask_visa = ""
        self.xss_chk_cookie_succ = ""
        self.buf_ovf_cookies_len_fail = ""
        self.redirect_wlist_succ = ""
        self.json_check_failure = ""
        self.xss_chk_post_reject = ""
        self.xss_chk_url_reject = ""
        self.form_consistency_succ = ""
        self.xml_limit_cdata_len = ""
        self.xml_check_failure = ""
        self.num_resets = ""
        self.referer_check_succ = ""
        self.sqlia_chk_post_succ = ""
        self.xss_chk_url_sanitize = ""
        self.cookie_encrypt_succ = ""
        self.buf_ovf_parameter_total_len_fail = ""
        self.soap_check_succ = ""
        self.max_cookies_fail = ""
        self.json_limit_array_value_count = ""
        self.xml_limit_entity_exp_depth = ""
        self.json_check_succ = ""
        self.resp_code_hidden = ""
        self.xml_sqlia_chk_fail = ""
        self.xss_chk_post_succ = ""
        self.form_consistency_fail = ""
        self.http_check_fail = ""
        self.url_check_succ = ""
        self.sqlia_chk_url_sanitize = ""
        self.xss_chk_cookie_reject = ""
        self.max_entities_fail = ""
        self.xml_limit_attr = ""
        self.http_method_check_fail = ""
        self.form_non_ssl_reject = ""
        self.xss_chk_post_sanitize = ""
        self.form_set_no_cache = ""
        self.xml_schema_succ = ""
        self.sqlia_chk_url_reject = ""
        self.xml_check_succ = ""
        self.sess_check_none = ""
        self.xml_limit_namespace = ""
        self.wsdl_fail = ""
        self.post_form_check_succ = ""
        self.buf_ovf_query_len_fail = ""
        self.sqlia_chk_post_reject = ""
        self.form_password_autocomplete = ""
        self.xml_xss_chk_fail = ""
        self.buf_ovf_url_len_fail = ""
        self.buf_ovf_cookie_len_fail = ""
        self.form_csrf_tag_succ = ""
        self.xss_chk_cookie_sanitize = ""
        self.xml_limit_entity_exp = ""
        self.ccn_mask_diners = ""
        self.sess_check_succ = ""
        self.json_limit_depth = ""
        self.cookie_encrypt_skip_rcache = ""
        self.learn_updates = ""
        self.req_denied = ""
        self.http_check_succ = ""
        self.req_allowed = ""
        self.json_limit_object_member_count = ""
        self.bot_check_fail = ""
        self.uri_wlist_fail = ""
        self.uri_blist_fail = ""
        self.xml_limit_namespace_uri_len = ""
        self.sqlia_chk_post_sanitize = ""
        self.ccn_mask_amex = ""
        self.num_drops = ""
        self.referer_check_fail = ""
        self.post_form_check_sanitize = ""
        self.cookie_decrypt_succ = ""
        self.max_parameters_fail = ""
        self.url_check_fail = ""
        self.xml_schema_fail = ""
        self.form_non_post_reject = ""
        self.buf_ovf_hdrs_len_fail = ""
        self.uri_wlist_succ = ""
        self.form_non_masked_password = ""
        self.buf_ovf_line_len_fail = ""
        self.ccn_mask_discover = ""
        self.ssn_mask = ""
        self.json_limit_string = ""
        self.resp_hdrs_filtered = ""
        self.ccn_mask_mastercard = ""
        self.xml_sqlia_chk_succ = ""
        self.max_hdrs_fail = ""
        self.xml_limit_attr_name_len = ""
        self.form_non_ssl_password = ""
        self.buf_ovf_hdr_value_len_fail = ""
        self.uri_blist_succ = ""
        self.sess_check_fail = ""
        self.buf_ovf_hdr_name_len_fail = ""
        self.resp_denied = ""
        self.pcre_mask = ""
        self.xml_limit_elem = ""
        self.buf_ovf_parameter_name_len_fail = ""
        self.xml_limit_attr_value_len = ""
        self.xml_limit_elem_depth = ""
        self.ccn_mask_jcb = ""
        self.cookie_decrypt_fail = ""
        self.buf_ovf_cookie_value_len_fail = ""
        self.buf_ovf_max_data_parse_fail = ""
        self.total_req = ""
        self.xml_limit_elem_name_len = ""
        self.url_check_learn = ""
        self.http_method_check_succ = ""
        self.xss_chk_url_succ = ""
        self.referer_check_redirect = ""
        self.post_form_check_reject = ""
        self.cookie_encrypt_fail = ""
        self.soap_check_failure = ""
        self.form_csrf_tag_fail = ""
        self.xml_xss_chk_succ = ""
        self.buf_ovf_post_size_fail = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.template = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Port(A10BaseClass):
    
    """Class Description::
    Statistics for the object template.

    Class port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "WAF Template Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/virtual-server/{name}/port/{port_number}+{protocol}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port_number","protocol"]

        self.b_key = "port"
        self.a10_url="/axapi/v3/slb/virtual-server/{name}/port/{port_number}+{protocol}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AccessList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_name: {"minLength": 1, "maxLength": 16, "type": "string", "description": "Apply an access list (Named Access List)", "format": "string"}
    :param acl_id: {"description": "ACL id", "format": "number", "maximum": 199, "minimum": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "access-list"
        self.DeviceProxy = ""
        self.acl_name = ""
        self.acl_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Lif(A10BaseClass):
    
    """Class Description::
    Logical interface.

    Class lif supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param mtu: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Interface mtu (Interface MTU, default 1500 (min MTU is 1280 for IPv6))", "format": "number", "optional": true, "type": "number"}
    :param ifnum: {"description": "Lif interface number", "format": "number", "type": "number", "maximum": 128, "minimum": 1, "optional": false}
    :param action: {"description": "'enable': Enable; 'disable': Disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/lif/{ifnum}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ifnum"]

        self.b_key = "lif"
        self.a10_url="/axapi/v3/interface/lif/{ifnum}"
        self.DeviceProxy = ""
        self.isis = {}
        self.bfd = {}
        self.ip = {}
        self.mtu = ""
        self.access_list = {}
        self.ifnum = ""
        self.action = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PerVlanLimit(A10BaseClass):
    
    """Class Description::
    Per vlan flooding packet limit.

    Class per-vlan-limit supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param unknown_ucast: {"description": "unknown unicast packets (per second limit)", "format": "number", "default": 1000, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param bcast: {"description": "broadcast packets (per second limit)", "format": "number", "default": 1000, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param mcast: {"description": "multicast packets (per second limit)", "format": "number", "default": 1000, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param ipmcast: {"description": "IP multicast packets (per second limit)", "format": "number", "default": 1000, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/per-vlan-limit`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "per-vlan-limit"
        self.a10_url="/axapi/v3/system/per-vlan-limit"
        self.DeviceProxy = ""
        self.unknown_ucast = ""
        self.bcast = ""
        self.mcast = ""
        self.ipmcast = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Logon(A10BaseClass):
    
    """Class Description::
    Authentication logon configuration.

    Class logon supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param form_based_list: {"minItems": 1, "items": {"type": "form-based"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"retry": {"description": "Specify max. number of failure retry (Specify retry count (1 ~ 32), default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 32, "minimum": 1, "type": "number"}, "name": {"description": "Specify form-based authentication logon name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "next-token-variable": {"description": "Specify next-token variable name in form submission", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "new-pin-variable": {"description": "Specify new-pin variable name in form submission", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "portal": {"type": "object", "properties": {"new-pin-page": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new PIN page name for RSA-RADIUS", "format": "string-rlx"}, "portal-name": {"description": "Specify portal name", "format": "string", "minLength": 1, "maxLength": 63, "not": "default-portal", "type": "string"}, "default-portal": {"default": 0, "not": "portal-name", "type": "number", "description": "Use default portal", "format": "flag"}, "next-token-page": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify next token page name for RSA-RADIUS", "format": "string-rlx"}, "failpage": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logon fail page name (portal fail page name)", "format": "string-rlx"}, "changepasswordpage": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify change password page name", "format": "string-rlx"}, "logon": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logon page name", "format": "string"}}}, "logon-page-cfg": {"type": "object", "properties": {"action-url": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify form submission action url", "format": "string-rlx"}, "username-variable": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username variable name in form submission", "format": "string-rlx"}, "password-variable": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify password variable name in form submission", "format": "string-rlx"}, "login-failure-message": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify login failure message shown in logon page (Specify error string, default is \"Invalid username or password. Please try again.\")", "format": "string-rlx"}}}, "cp-page-cfg": {"type": "object", "properties": {"cp-cfm-pwd-enum": {"enum": ["changepassword-password-confirm-variable"], "type": "string", "description": "'changepassword-password-confirm-variable': Specify password confirm variable name in form submission; ", "format": "enum"}, "cp-cfm-pwd-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify password confirm variable name", "format": "string-rlx"}, "cp-new-pwd-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new password variable name", "format": "string-rlx"}, "changepassword-url": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify changepassword form submission action url (changepassword action url)", "format": "string-rlx"}, "cp-new-pwd-enum": {"enum": ["changepassword-new-password-variable"], "type": "string", "description": "'changepassword-new-password-variable': Specify new password variable name in form submission; ", "format": "enum"}, "cp-old-pwd-enum": {"enum": ["changepassword-old-password-variable"], "type": "string", "description": "'changepassword-old-password-variable': Specify old password variable name in form submission; ", "format": "enum"}, "cp-user-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username variable name", "format": "string-rlx"}, "cp-old-pwd-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify old password variable name", "format": "string-rlx"}, "cp-user-enum": {"enum": ["changepassword-username-variable"], "type": "string", "description": "'changepassword-username-variable': Specify username variable name in form submission; ", "format": "enum"}}}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/logon/form-based/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/logon`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "logon"
        self.a10_url="/axapi/v3/aam/authentication/logon"
        self.DeviceProxy = ""
        self.form_based_list = []
        self.http_authenticate = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Port(A10BaseClass):
    
    """Class Description::
    Virtual Port.

    Class port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param protocol: {"optional": false, "enum": ["dns-udp"], "type": "string", "description": "'dns-udp': DNS service over UDP; ", "format": "enum"}
    :param precedence: {"default": 0, "optional": true, "type": "number", "description": "Set auto NAT pool as higher precedence for source NAT", "format": "flag"}
    :param auto: {"default": 0, "optional": true, "type": "number", "description": "Configure auto NAT for the vport", "format": "flag"}
    :param template_policy: {"description": "Policy Template (Policy template name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/cgnv6/template/policy"}
    :param port_number: {"description": "Port", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}
    :param template_dns: {"description": "DNS template (DNS template name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/cgnv6/template/dns"}
    :param service_group: {"description": "Bind a Service Group to this Virtual Server (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/cgnv6/service-group"}
    :param action: {"description": "'enable': Enable; 'disable': Disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param pool: {"description": "Specify NAT pool or pool group", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/dns64-virtualserver/{name}/port/{port_number}+{protocol}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port_number","protocol"]

        self.b_key = "port"
        self.a10_url="/axapi/v3/cgnv6/dns64-virtualserver/{name}/port/{port_number}+{protocol}"
        self.DeviceProxy = ""
        self.protocol = ""
        self.precedence = ""
        self.auto = ""
        self.template_policy = ""
        self.port_number = ""
        self.template_dns = ""
        self.service_group = ""
        self.action = ""
        self.pool = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ConnRateLimit(A10BaseClass):
    
    """Class Description::
    Set rate limiting on virtual ports.

    Class conn-rate-limit supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param src_ip_list: {"minItems": 1, "items": {"type": "src-ip"}, "uniqueItems": true, "array": [{"required": ["protocol"], "properties": {"protocol": {"optional": false, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': Set TCP connection rate limit; 'udp': Set UDP packet rate limit; ", "format": "enum"}, "log": {"default": 0, "optional": true, "type": "number", "description": "Send log if threshold exceeded", "format": "flag"}, "lock-out": {"description": "Set lockout period in seconds if threshold exceeded", "format": "number", "type": "number", "maximum": 3600, "minimum": 1, "optional": true}, "limit": {"description": "Set max packets per period", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}, "exceed-action": {"default": 0, "optional": true, "type": "number", "description": "Set action if threshold exceeded", "format": "flag"}, "shared": {"default": 0, "optional": true, "type": "number", "description": "Set threshold shared amongst all virtual ports", "format": "flag"}, "limit-period": {"optional": true, "enum": ["100", "1000"], "type": "string", "description": "'100': 100 ms; '1000': 1000 ms; ", "format": "enum"}}}], "type": "array", "$ref": "/axapi/v3/slb/common/conn-rate-limit/src-ip/{protocol}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/common/conn-rate-limit`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "conn-rate-limit"
        self.a10_url="/axapi/v3/slb/common/conn-rate-limit"
        self.DeviceProxy = ""
        self.src_ip_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Partition(A10BaseClass):
    
    """    :param partition_name: {"description": "Object partition name", "format": "string", "minLength": 1, "optional": true, "maxLength": 14, "type": "string"}
    :param id: {"description": "Specify unique Partition id", "format": "number", "optional": true, "maximum": 127, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    hard delete a partition.

    Class partition supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/delete/partition`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "partition"
        self.a10_url="/axapi/v3/delete/partition"
        self.DeviceProxy = ""
        self.partition_name = ""
        self.A10WW_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param last_server: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.last_server = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DnsNsRecord(A10BaseClass):
    
    """Class Description::
    Operational Status for the object dns-ns-record.

    Class dns-ns-record supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ns_name: {"description": "Specify Domain Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-ns-record/{ns_name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns-ns-record"
        self.a10_url="/axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-ns-record/{ns_name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.ns_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class NexthopTrigger(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param delay: {"description": "Configure nexthop trigger delay time interval (Nexthop Trigger Delay time interval between 1 and 100)", "minimum": 1, "type": "number", "maximum": 100, "format": "number"}
    :param enable: {"default": 0, "type": "number", "description": "Enable the nexthop tracking functionality", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "nexthop-trigger"
        self.DeviceProxy = ""
        self.delay = ""
        self.enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Bgp(A10BaseClass):
    
    """Class Description::
    Border Gateway Protocol (BGP).

    Class bgp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param extended_asn_cap: {"default": 0, "optional": true, "type": "number", "description": "Enable the router to send 4-octet ASN capabilities", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/bgp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "bgp"
        self.a10_url="/axapi/v3/bgp"
        self.DeviceProxy = ""
        self.nexthop_trigger = {}
        self.extended_asn_cap = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Nat64(A10BaseClass):
    
    """Class Description::
    Configure NAT64.

    Class nat64 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param prefix_list: {"minItems": 1, "items": {"type": "prefix"}, "uniqueItems": true, "array": [{"required": ["prefix-val"], "properties": {"vrid": {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}, "prefix-val": {"optional": false, "type": "string", "description": "NAT64 Prefix", "format": "ipv6-address-plen"}, "class-list": {"description": "Class-list to match for NAT64", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/nat64/prefix/{prefix-val}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat64`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "nat64"
        self.a10_url="/axapi/v3/cgnv6/nat64"
        self.DeviceProxy = ""
        self.alg = {}
        self.fragmentation = {}
        self.A10WW_global = {}
        self.prefix_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param client_eprt_request: {"description": "EPRT Requests From Client", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param server_epsv_reply: {"description": "EPSV Replies From Server", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param client_port_request: {"description": "PORT Requests From Client", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param server_pasv_reply: {"description": "PASV Replies From Server", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.client_eprt_request = ""
        self.server_epsv_reply = ""
        self.client_port_request = ""
        self.server_pasv_reply = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ftp(A10BaseClass):
    
    """Class Description::
    Statistics for the object ftp.

    Class ftp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/stateful-firewall/alg/ftp/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ftp"
        self.a10_url="/axapi/v3/cgnv6/stateful-firewall/alg/ftp/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Rt(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"type": "string", "description": "VPN extended community", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rt"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Soo(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"type": "string", "description": "VPN extended community", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "soo"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Extcommunity(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "extcommunity"
        self.DeviceProxy = ""
        self.rt = {}
        self.soo = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Origin(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param egp: {"default": 0, "not-list": ["igp", "incomplete"], "type": "number", "description": "remote EGP", "format": "flag"}
    :param incomplete: {"default": 0, "not-list": ["egp", "igp"], "type": "number", "description": "unknown heritage", "format": "flag"}
    :param igp: {"default": 0, "not-list": ["egp", "incomplete"], "type": "number", "description": "local IGP", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "origin"
        self.DeviceProxy = ""
        self.egp = ""
        self.incomplete = ""
        self.igp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AggregatorAs(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip: {"type": "string", "description": "IP address of aggregator", "format": "ipv4-address"}
    :param asn: {"description": "AS number", "minimum": 1, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "aggregator-as"
        self.DeviceProxy = ""
        self.ip = ""
        self.asn = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Aggregator(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "aggregator"
        self.DeviceProxy = ""
        self.aggregator_as = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Weight(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param weight_val: {"description": "Weight value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "weight"
        self.DeviceProxy = ""
        self.weight_val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Level(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Export into a level-1 area; 'level-1-2': Export into level-1 and level-2; 'level-2': Export into level-2 sub-domain; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "level"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NextHop(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param address: {"type": "string", "description": "IP address of next hop", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "next-hop"
        self.DeviceProxy = ""
        self.address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ip(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip"
        self.DeviceProxy = ""
        self.next_hop = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Metric(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Metric value", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "metric"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AsPath(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param num: {"description": "AS number", "minimum": 1, "type": "number", "maximum": 4294967295, "format": "number"}
    :param num2: {"description": "AS number", "minimum": 1, "type": "number", "maximum": 4294967295, "format": "number"}
    :param prepend: {"type": "string", "description": "Prepend to the as-path (AS number)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "as-path"
        self.DeviceProxy = ""
        self.num = ""
        self.num2 = ""
        self.prepend = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CommList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param name: {"description": "Community-list name", "format": "string", "minLength": 1, "not-list": ["v-std", "v-exp"], "maxLength": 128, "type": "string"}
    :param v_std: {"description": "Community-list number (standard)", "format": "number", "not-list": ["v-exp", "name"], "maximum": 99, "minimum": 1, "type": "number"}
    :param v_exp_delete: {"default": 0, "type": "number", "description": "Delete matching communities", "format": "flag"}
    :param v_exp: {"description": "Community-list number (expanded)", "format": "number", "not-list": ["v-std", "name"], "maximum": 199, "minimum": 100, "type": "number"}
    :param name_delete: {"default": 0, "type": "number", "description": "Delete matching communities", "format": "flag"}
    :param delete: {"default": 0, "type": "number", "description": "Delete matching communities", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "comm-list"
        self.DeviceProxy = ""
        self.name = ""
        self.v_std = ""
        self.v_exp_delete = ""
        self.v_exp = ""
        self.name_delete = ""
        self.delete = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LocalPreference(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param val: {"description": "Preference value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "local-preference"
        self.DeviceProxy = ""
        self.val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Tag(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"description": "Tag value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tag"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Local(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param address: {"type": "string", "description": "IPv6 address of next hop", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "local"
        self.DeviceProxy = ""
        self.address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NextHop1(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param address: {"type": "string", "description": "global address of next hop", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "next-hop-1"
        self.DeviceProxy = ""
        self.local = {}
        self.address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6"
        self.DeviceProxy = ""
        self.next_hop_1 = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DampeningCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dampening_max_supress: {"description": "Maximum duration to suppress a stable route(minutes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param dampening: {"default": 0, "type": "number", "description": "Enable route-flap dampening", "format": "flag"}
    :param dampening_penalty: {"description": "Un-reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}
    :param dampening_half_time: {"description": "Reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}
    :param dampening_supress: {"description": "Value to start suppressing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}
    :param dampening_reuse: {"description": "Value to start reusing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dampening-cfg"
        self.DeviceProxy = ""
        self.dampening_max_supress = ""
        self.dampening = ""
        self.dampening_penalty = ""
        self.dampening_half_time = ""
        self.dampening_supress = ""
        self.dampening_reuse = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class OriginatorId(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param originator_ip: {"type": "string", "description": "IP address of originator", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "originator-id"
        self.DeviceProxy = ""
        self.originator_ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MetricType(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"enum": ["external", "internal", "type-1", "type-2"], "type": "string", "description": "'external': IS-IS external metric type; 'internal': IS-IS internal metric type; 'type-1': OSPF external type 1 metric; 'type-2': OSPF external type 2 metric; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "metric-type"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Set(A10BaseClass):
    
    """Class Description::
    Set values in destination routing protocol.

    Class set supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param atomic_aggregate: {"default": 0, "optional": true, "type": "number", "description": "BGP atomic aggregate attribute", "format": "flag"}
    :param community: {"optional": true, "type": "string", "description": "BGP community attribute", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/route-map/{tag}+{action}+{sequence}/set`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "set"
        self.a10_url="/axapi/v3/route-map/{tag}+{action}+{sequence}/set"
        self.DeviceProxy = ""
        self.extcommunity = {}
        self.origin = {}
        self.aggregator = {}
        self.weight = {}
        self.level = {}
        self.ip = {}
        self.metric = {}
        self.as_path = {}
        self.comm_list = {}
        self.atomic_aggregate = ""
        self.community = ""
        self.local_preference = {}
        self.tag = {}
        self.ipv6 = {}
        self.dampening_cfg = {}
        self.originator_id = {}
        self.metric_type = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PriorityPartition(A10BaseClass):
    
    """Class Description::
    Configure partition to always poll for techreport.

    Class priority-partition supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param part_name: {"description": "Name of partition always want to show in showtech (shared is always shown by default)", "format": "string", "minLength": 1, "optional": false, "maxLength": 14, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/techreport/priority-partition/{part_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "part_name"]

        self.b_key = "priority-partition"
        self.a10_url="/axapi/v3/techreport/priority-partition/{part_name}"
        self.DeviceProxy = ""
        self.part_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ssl_failed_ca_verification: {"description": "SSL Cert Auth Verification Errors", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param server_ssl_count_total: {"description": "Total SSL Server Count", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param tcp_est_counter: {"description": "TCP Established", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param conn_smp_type_1_available: {"description": "Conn SMP Type 1 Available", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "8"}
    :param total_l4_packet_count: {"description": "Total L4 Packet Count", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param total_l7_conn: {"description": "Total L7 Conn", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param conn_smp_aged_counter: {"description": "Conn SMP Aged", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param reverse_nat_tcp_ounter: {"description": "Reverse NAT TCP", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param conn_type_1_available: {"description": "Conn Type 1 Available", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param ssl_server_cert_error: {"description": "SSL Server Cert Errors", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param ip_counter: {"description": "IP Count", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param total_l2l3_conn: {"description": "Totl L2/L3 Connections", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param ssl_failed_total: {"description": "Total SSL Failures", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param conn_type_3_available: {"description": "Conn Type 3 Available", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param conn_type_4_available: {"description": "Conn Type 4 Available", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param conn_type_2_available: {"description": "Conn Type 2 Available", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param conn_smp_type_0_available: {"description": "Conn SMP Type 0 Available", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "8"}
    :param total_l7_packet_count: {"description": "Total L7 Packet Count", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param total_tcp_conn: {"description": "Total TCP Conn", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param tcp_half_open_counter: {"description": "TCP Half Open", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param ssl_client_cert_auth_fail: {"description": "SSL Client Cert Auth Failures", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param ssl_count_total: {"description": "Total SSL Count", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param conn_freed_counter: {"description": "Conn Freed", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param conn_type_0_available: {"description": "Conn Type 0 Available", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param conn_smp_free_counter: {"description": "Conn SMP Free", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param curr_free_conn: {"description": "Curr Free Conn", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param client_ssl_reuse_total: {"description": "Total SSL Client Reuse", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param udp_counter: {"description": "UDP Count", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param conn_smp_type_2_available: {"description": "Conn SMP Type 2 Available", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "8"}
    :param reverse_nat_udp_ounter: {"description": "Reverse NAT UDP", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param client_ssl_ctx_malloc_failure: {"description": "Client SSL Ctx malloc Failures", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param tcp_syn_half_open_counter: {"description": "TCP SYN Half Open", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param total_l4_conn_proxy: {"description": "Total L4 Conn Proxy Count", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param conn_smp_type_3_available: {"description": "Conn SMP Type 3 Available", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "8"}
    :param conn_smp_alloc_counter: {"description": "Conn SMP Alloc", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param conn_counter: {"description": "Conn Count", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param other_counter: {"description": "Non TCP/UDP IP sessions", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param server_ssl_count_curr: {"description": "Current SSL Server Count", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param server_ssl_reuse_total: {"description": "Total SSL Server Reuse", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param total_ip_nat_donn: {"description": "Total IP Nat Conn", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param conn_smp_type_4_available: {"description": "Conn SMP Type 4 Available", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "8"}
    :param tcp_half_close_counter: {"description": "TCP Half Closed", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param total_l4_conn: {"description": "Total L4 Count", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param ssl_count_curr: {"description": "Curr SSL Count", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.ssl_failed_ca_verification = ""
        self.server_ssl_count_total = ""
        self.tcp_est_counter = ""
        self.conn_smp_type_1_available = ""
        self.total_l4_packet_count = ""
        self.total_l7_conn = ""
        self.conn_smp_aged_counter = ""
        self.reverse_nat_tcp_ounter = ""
        self.conn_type_1_available = ""
        self.ssl_server_cert_error = ""
        self.ip_counter = ""
        self.total_l2l3_conn = ""
        self.ssl_failed_total = ""
        self.conn_type_3_available = ""
        self.conn_type_4_available = ""
        self.conn_type_2_available = ""
        self.conn_smp_type_0_available = ""
        self.total_l7_packet_count = ""
        self.total_tcp_conn = ""
        self.tcp_half_open_counter = ""
        self.ssl_client_cert_auth_fail = ""
        self.ssl_count_total = ""
        self.conn_freed_counter = ""
        self.conn_type_0_available = ""
        self.conn_smp_free_counter = ""
        self.curr_free_conn = ""
        self.client_ssl_reuse_total = ""
        self.udp_counter = ""
        self.conn_smp_type_2_available = ""
        self.reverse_nat_udp_ounter = ""
        self.client_ssl_ctx_malloc_failure = ""
        self.tcp_syn_half_open_counter = ""
        self.total_l4_conn_proxy = ""
        self.conn_smp_type_3_available = ""
        self.conn_smp_alloc_counter = ""
        self.conn_counter = ""
        self.other_counter = ""
        self.server_ssl_count_curr = ""
        self.server_ssl_reuse_total = ""
        self.total_ip_nat_donn = ""
        self.conn_smp_type_4_available = ""
        self.tcp_half_close_counter = ""
        self.total_l4_conn = ""
        self.ssl_count_curr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Session(A10BaseClass):
    
    """Class Description::
    Statistics for the object session.

    Class session supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/session/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "session"
        self.a10_url="/axapi/v3/system/session/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Reboot(A10BaseClass):
    
    """    :param all: {"default": 0, "optional": true, "type": "number", "description": "Reboot all devices when VCS is enabled, or only this device itself if VCS is not enabled", "format": "flag"}
    :param day_of_month: {"description": "Day of the Month", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}
    :param reason_3: {"description": "Reason for Reboot", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param reason_2: {"description": "Reason for Reboot", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param time: {"optional": true, "type": "string", "description": "Time to Reboot (hh:mm)", "format": "time-hhmm"}
    :param month_2: {"optional": true, "enum": ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"], "type": "string", "description": "'January': Month of the year; 'February': Month of the year; 'March': Month of the year; 'April': Month of the year; 'May': Month of the year; 'June': Month of the year; 'July': Month of the r; 'August': Month of the year; 'September': Month of the year; 'October': Month of the year; 'November': Month of the year; 'December': Month of the year; ", "format": "enum"}
    :param month: {"optional": true, "enum": ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"], "type": "string", "description": "'January': Month of the year; 'February': Month of the year; 'March': Month of the year; 'April': Month of the year; 'May': Month of the year; 'June': Month of the year; 'July': Month of the year; 'August': Month of the year; 'September': Month of the year; 'October': Month of the year; 'November': Month of the year; 'December': Month of the year; ", "format": "enum"}
    :param cancel: {"default": 0, "optional": true, "type": "number", "description": "Cancel Pending Reboot", "format": "flag"}
    :param reason: {"description": "Reason for Reboot", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param at: {"default": 0, "optional": true, "type": "number", "description": "Reboot at a Specific time/date", "format": "flag"}
    :param in: {"optional": true, "type": "string", "description": "Reboot after a time interval (Time in hours and minutes)", "format": "time-hhmm"}
    :param device: {"description": "Reboot a specific device when VCS is enabled (device id)", "format": "number", "type": "number", "maximum": 8, "minimum": 1, "optional": true}
    :param day_of_month_2: {"description": "Day of the Month", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Reboot the System.

    Class reboot supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/reboot`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "reboot"
        self.a10_url="/axapi/v3/reboot"
        self.DeviceProxy = ""
        self.A10WW_all = ""
        self.day_of_month = ""
        self.reason_3 = ""
        self.reason_2 = ""
        self.time = ""
        self.month_2 = ""
        self.month = ""
        self.cancel = ""
        self.reason = ""
        self.at = ""
        self.A10WW_in = ""
        self.device = ""
        self.day_of_month_2 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class HealthCheckList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param status: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param retries: {"type": "number", "format": "number"}
    :param down_state: {"type": "number", "format": "number"}
    :param up_retries: {"type": "number", "format": "number"}
    :param down_cause: {"type": "number", "format": "number"}
    :param partition_id: {"type": "number", "format": "number"}
    :param up_cause: {"type": "number", "format": "number"}
    :param ip_address: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param total_retry: {"type": "number", "format": "number"}
    :param health_monitor: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param port: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "health-check-list"
        self.DeviceProxy = ""
        self.status = ""
        self.retries = ""
        self.down_state = ""
        self.up_retries = ""
        self.down_cause = ""
        self.partition_id = ""
        self.up_cause = ""
        self.ip_address = ""
        self.total_retry = ""
        self.health_monitor = ""
        self.port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param health_check_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"status": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "retries": {"type": "number", "format": "number"}, "down-state": {"type": "number", "format": "number"}, "up-retries": {"type": "number", "format": "number"}, "down-cause": {"type": "number", "format": "number"}, "partition-id": {"type": "number", "format": "number"}, "up-cause": {"type": "number", "format": "number"}, "ip-address": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "total-retry": {"type": "number", "format": "number"}, "health-monitor": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "port": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.health_check_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HealthStat(A10BaseClass):
    
    """Class Description::
    Operational Status for the object health-stat.

    Class health-stat supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/health-stat/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "health-stat"
        self.a10_url="/axapi/v3/slb/health-stat/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class EthList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param eth_end: {"type": "number", "description": "Ethernet interface to sample", "format": "interface"}
    :param eth_start: {"type": "number", "description": "Ethernet interface to sample", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "eth-list"
        self.DeviceProxy = ""
        self.eth_end = ""
        self.eth_start = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VeList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve_end: {"$ref": "/axapi/v3/interface/ve", "type": "number", "description": "VE interface to sample", "format": "number"}
    :param ve_start: {"$ref": "/axapi/v3/interface/ve", "type": "number", "description": "VE interface to sample", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ve-list"
        self.DeviceProxy = ""
        self.ve_end = ""
        self.ve_start = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Polling(A10BaseClass):
    
    """Class Description::
    Configure sFlow counter polling on specified source.

    Class polling supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param cpu_usage: {"default": 0, "optional": true, "type": "number", "description": "Polling CPU usage", "format": "flag"}
    :param eth_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"eth-end": {"type": "number", "description": "Ethernet interface to sample", "format": "interface"}, "optional": true, "eth-start": {"type": "number", "description": "Ethernet interface to sample", "format": "interface"}}}]}
    :param http_counter: {"default": 0, "optional": true, "type": "number", "description": "Polling HTTP counters", "format": "flag"}
    :param ve_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve-end": {"$ref": "/axapi/v3/interface/ve", "type": "number", "description": "VE interface to sample", "format": "number"}, "ve-start": {"$ref": "/axapi/v3/interface/ve", "type": "number", "description": "VE interface to sample", "format": "number"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/sflow/polling`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "polling"
        self.a10_url="/axapi/v3/sflow/polling"
        self.DeviceProxy = ""
        self.cpu_usage = ""
        self.eth_list = []
        self.http_counter = ""
        self.ve_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Overage(A10BaseClass):
    
    """Class Description::
    Set overage parameters.

    Class overage supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param kb: {"description": "Number of KB", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}
    :param mb: {"description": "Number of MB", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}
    :param seconds: {"description": "Number of seconds", "format": "number", "type": "number", "maximum": 59, "minimum": 0, "optional": true}
    :param bytes: {"description": "Number of bytes", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}
    :param days: {"description": "Number of days", "format": "number", "type": "number", "maximum": 365, "minimum": 0, "optional": true}
    :param hours: {"description": "Number of hours", "format": "number", "type": "number", "maximum": 23, "minimum": 0, "optional": true}
    :param gb: {"description": "Number of GB", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param minutes: {"description": "Number of minutes", "format": "number", "type": "number", "maximum": 59, "minimum": 0, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/license-manager/overage`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "overage"
        self.a10_url="/axapi/v3/license-manager/overage"
        self.DeviceProxy = ""
        self.kb = ""
        self.mb = ""
        self.seconds = ""
        self.A10WW_bytes = ""
        self.days = ""
        self.hours = ""
        self.gb = ""
        self.minutes = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Authorize_failure: {"description": "Total Authorization Failure", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param Other_error: {"description": "Total Other Error", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param Request: {"description": "Total Request", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param Authen_success: {"description": "Total Authentication Success", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param Access_challenge: {"description": "Total Access-Challenge Message Receive", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param Authen_failure: {"description": "Total Authentication Failure", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param Timeout_error: {"description": "Total Timeout", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param Authorize_success: {"description": "Total Authorization Success", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.Authorize_failure = ""
        self.Other_error = ""
        self.Request = ""
        self.Authen_success = ""
        self.Access_challenge = ""
        self.Authen_failure = ""
        self.Timeout_error = ""
        self.Authorize_success = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Radius(A10BaseClass):
    
    """Class Description::
    Statistics for the object radius.

    Class radius supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param instance_list: {"minItems": 1, "items": {"type": "instance"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"stats": {"type": "object", "properties": {"Authorize_failure": {"description": "Authorization Failure", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}, "Other_error": {"description": "Other Error", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}, "Request": {"description": "Request", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}, "Authen_success": {"description": "Authentication Success", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}, "Access_challenge": {"description": "Access-Challenge Message Receive", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}, "Authen_failure": {"description": "Authentication Failure", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}, "Timeout_error": {"description": "Timeout", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}, "Authorize_success": {"description": "Authorization Success", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}}}, "name": {"description": "Specify RADIUS authentication server name", "format": "string-rlx", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/server/radius/instance/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/server/radius/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "radius"
        self.a10_url="/axapi/v3/aam/authentication/server/radius/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.instance_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param select_client_conn: {"description": "Client conn selection", "format": "counter", "type": "number", "oid": "63", "optional": true, "size": "2"}
    :param select_client_fail: {"description": "Select failed", "format": "counter", "type": "number", "oid": "67", "optional": true, "size": "2"}
    :param msg_proxy_server_incomplete: {"description": "Incomplete", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "2"}
    :param select_client_by_conn: {"description": "Select by conn", "format": "counter", "type": "number", "oid": "66", "optional": true, "size": "2"}
    :param AX_response_directly: {"description": "Number of packet which AX responds directly", "format": "counter", "type": "number", "oid": "62", "optional": true, "size": "2"}
    :param select_client_by_req: {"description": "Select by request", "format": "counter", "type": "number", "oid": "64", "optional": true, "size": "2"}
    :param select_server_by_req: {"description": "Select by request", "format": "counter", "type": "number", "oid": "69", "optional": true, "size": "2"}
    :param select_server_by_conn: {"description": "Select server conn by client conn", "format": "counter", "type": "number", "oid": "71", "optional": true, "size": "2"}
    :param msg_proxy_client_send_success: {"description": "Sent to server", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param msg_proxy_client_drop: {"description": "AX responds directly", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param msg_proxy_total: {"description": "Total SMPP Proxy", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param select_server_from_list: {"description": "Select by roundbin", "format": "counter", "type": "number", "oid": "70", "optional": true, "size": "2"}
    :param msg_proxy_current: {"description": "Curr SMPP Proxy", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param msg_proxy_client_fail: {"description": "Number of SMPP messages received from client but failed to forward to server", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param msg_proxy_create_server_conn: {"description": "Server conn created", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "2"}
    :param msg_proxy_server_send_success: {"description": "Sent to client", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param msg_proxy_server_fail: {"description": "Number of SMPP messages received from server but failed to forward to client", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "2"}
    :param select_client_from_list: {"description": "Select by roundbin", "format": "counter", "type": "number", "oid": "65", "optional": true, "size": "2"}
    :param msg_proxy_client_incomplete: {"description": "Incomplete", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param msg_proxy_server_drop: {"description": "Number of the packet AX drop", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "2"}
    :param select_server_fail: {"description": "Fail to select server conn", "format": "counter", "type": "number", "oid": "72", "optional": true, "size": "2"}
    :param msg_proxy_start_server_conn: {"description": "Number of server connection created successfully", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "2"}
    :param msg_proxy_fail_start_server_conn: {"description": "Number of server connection created failed", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "2"}
    :param select_server_conn: {"description": "Server conn selection", "format": "counter", "type": "number", "oid": "68", "optional": true, "size": "2"}
    :param msg_proxy_server_recv: {"description": "Server message rcvd", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param msg_proxy_client_connection: {"description": "Connecting server", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param msg_proxy_client_recv: {"description": "Client message rcvd", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.select_client_conn = ""
        self.select_client_fail = ""
        self.msg_proxy_server_incomplete = ""
        self.select_client_by_conn = ""
        self.AX_response_directly = ""
        self.select_client_by_req = ""
        self.select_server_by_req = ""
        self.select_server_by_conn = ""
        self.msg_proxy_client_send_success = ""
        self.msg_proxy_client_drop = ""
        self.msg_proxy_total = ""
        self.select_server_from_list = ""
        self.msg_proxy_current = ""
        self.msg_proxy_client_fail = ""
        self.msg_proxy_create_server_conn = ""
        self.msg_proxy_server_send_success = ""
        self.msg_proxy_server_fail = ""
        self.select_client_from_list = ""
        self.msg_proxy_client_incomplete = ""
        self.msg_proxy_server_drop = ""
        self.select_server_fail = ""
        self.msg_proxy_start_server_conn = ""
        self.msg_proxy_fail_start_server_conn = ""
        self.select_server_conn = ""
        self.msg_proxy_server_recv = ""
        self.msg_proxy_client_connection = ""
        self.msg_proxy_client_recv = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Smpp(A10BaseClass):
    
    """Class Description::
    Statistics for the object smpp.

    Class smpp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/smpp/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "smpp"
        self.a10_url="/axapi/v3/slb/smpp/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Source(A10BaseClass):
    
    """Class Description::
    Source.

    Class source supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param static_list: {"minItems": 1, "items": {"type": "static"}, "uniqueItems": true, "array": [{"required": ["src-address", "nat-address"], "properties": {"nat-address": {"optional": false, "type": "string", "description": "NAT Address", "format": "ipv4-address"}, "vrid": {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}, "src-address": {"optional": false, "type": "string", "description": "Original Source Address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/nat/inside/source/static/{src-address}+{nat-address}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat/inside/source`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "source"
        self.a10_url="/axapi/v3/cgnv6/nat/inside/source"
        self.DeviceProxy = ""
        self.static_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


